### Sampling code in R for hylid body size range regression
### We use this program to see how these distributions change as a consequence of community size

### Use hylid data from paper
setwd("~/Dropbox/Active Research/Website April 2013/Code for website/Ready to go!/Hylid local diversity")
allhylids<-read.table("Hylid_SVL_HylidsAll.txt",header=T)
data<-read.table("hylid_sizelocaldiv_7Nov.txt",header=T)

### Calculate original regression (logged on both for appropriateness)
lm_range<-lm(log(data$Nspec)~data$range_actual)

### Create set variables for the simulation
body<-allhylids$M # Body sizes (all)
iter<-1000 # This is the number of times you want to sample during the simulation
comm_size<-c(1:36) # This is the number of community sizes you want to examine; this in principle could be anything, but here I am using the maximum known hylid community size

### Make matrices for storage of random communities
range_body<-matrix(data=NA,nrow=length(comm_size),ncol=iter)

### Loop to (1) generate 'random' communities, then (2) calculate summary stats (the actual communities are not needed for downstream analyses)
for (i in comm_size) {
    for (j in 1:iter) {
        k<-sample(body, i, replace = T)
        range_body[i,j]=max(k)-min(k) # Note that it does not really matter that we have 0.0 in all the 1-species model communities, because they are not used
        rm(k)
    }
}

### Plot values by community size (quite messy)
#plot(log(comm_size),range_body[,1])
#apply(range_body,MARGIN=2,function(x){points(log(comm_size),x)})

### Now need to draw randomly to produce null regressions
actualcomms<-data$Nspec
null_samples_range<-matrix(data=NA,nrow=iter,ncol=length(actualcomms))
for (i in 1:iter){
	for (j in seq(actualcomms)){
		null_samples_range[i,j]<-sample(range_body[actualcomms[j],],1)
	}
}

## Set up an empty matrix to store results
Null_dist<-matrix(data=NA,nrow=iter,ncol=4)#Where the first column is P-value, second is R2, third is slope, and fourth is t-value
colnames(Null_dist)<-c("P.value","R-sqr","slope","t-value")

### Loop over analyses (just for "ranges" at the moment)
for (i in 1:iter){
	FAKE<-lm(log(actualcomms)~null_samples_range[i,])
	Null_dist[i,1]<-coef(summary(FAKE))[2,4]
	Null_dist[i,2]<-summary(FAKE)$"adj.r.squared"
	Null_dist[i,3]<-coef(summary(FAKE))[2,1]
	Null_dist[i,4]<-coef(summary(FAKE))[2,3]
}

### Calculate confidence intervals on each of these vectors of null results
Conf_inter_95<-matrix(data=NA,nrow=2,ncol=3)#empty results matrix
Order_null_results<-matrix(data=NA,nrow=iter,ncol=4)
for (m in 1:3){
	Order_null_results[,m]<-sort(Null_dist[,m])
	Conf_inter_95[1,m]<-Order_null_results[round(iter*0.025),m]
	Conf_inter_95[2,m]<-Order_null_results[round(iter*0.975),m]
}
Conf_inter_95#shows results note that I didnt do it for F-stat b/c of below

### Calculate P-value of t-stat for actual analysis
# Find how many of simulated values are below ACTUAL values then divide by "iter" to calculate one-sided P-value
Pval_tstat<-(sum(Null_dist[,4]>=coef(summary(lm_range))[2,3]))/iter
Pval_tstat

### Plot histogram of T-stat
hist(Null_dist[,4])



